Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(123)

Unified Diff: ios/web_view/internal/web_view_browser_state.h

Issue 2715043002: Replace prefix of ios/web_view C++ classes. (Closed)
Patch Set: Respond to comments. Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ios/web_view/internal/web_view_browser_state.h
diff --git a/ios/web_view/internal/criwv_browser_state.h b/ios/web_view/internal/web_view_browser_state.h
similarity index 62%
rename from ios/web_view/internal/criwv_browser_state.h
rename to ios/web_view/internal/web_view_browser_state.h
index cb2e4f83139987a8009643e826f901db20471443..3c321b0c0ce358553079f77c01a60e8aabb915e5 100644
--- a/ios/web_view/internal/criwv_browser_state.h
+++ b/ios/web_view/internal/web_view_browser_state.h
@@ -2,8 +2,8 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef IOS_WEB_VIEW_INTERNAL_CRIWV_BROWSER_STATE_H_
-#define IOS_WEB_VIEW_INTERNAL_CRIWV_BROWSER_STATE_H_
+#ifndef IOS_WEB_VIEW_INTERNAL_WEB_VIEW_BROWSER_STATE_H_
+#define IOS_WEB_VIEW_INTERNAL_WEB_VIEW_BROWSER_STATE_H_
#include <memory>
@@ -19,13 +19,14 @@ class PrefRegistrySyncable;
namespace ios_web_view {
-class CRIWVURLRequestContextGetter;
+class WebViewURLRequestContextGetter;
-// CWV implementation of BrowserState. Can only be called from the UI thread.
-class CRIWVBrowserState : public web::BrowserState {
+// WebView implementation of BrowserState. Can only be used only on the UI
+// thread.
+class WebViewBrowserState : public web::BrowserState {
public:
- explicit CRIWVBrowserState(bool off_the_record);
- ~CRIWVBrowserState() override;
+ explicit WebViewBrowserState(bool off_the_record);
+ ~WebViewBrowserState() override;
// web::BrowserState implementation.
bool IsOffTheRecord() const override;
@@ -35,8 +36,9 @@ class CRIWVBrowserState : public web::BrowserState {
// Returns the associated PrefService.
PrefService* GetPrefs();
- // Converts from web::BrowserState to CRIWVBrowserState.
- static CRIWVBrowserState* FromBrowserState(web::BrowserState* browser_state);
+ // Converts from web::BrowserState to WebViewBrowserState.
+ static WebViewBrowserState* FromBrowserState(
+ web::BrowserState* browser_state);
private:
// Registers the preferences for this BrowserState.
@@ -49,14 +51,14 @@ class CRIWVBrowserState : public web::BrowserState {
bool off_the_record_;
// The request context getter for this BrowserState object.
- scoped_refptr<CRIWVURLRequestContextGetter> request_context_getter_;
+ scoped_refptr<WebViewURLRequestContextGetter> request_context_getter_;
// The PrefService associated with this BrowserState.
std::unique_ptr<PrefService> prefs_;
- DISALLOW_COPY_AND_ASSIGN(CRIWVBrowserState);
+ DISALLOW_COPY_AND_ASSIGN(WebViewBrowserState);
};
} // namespace ios_web_view
-#endif // IOS_WEB_VIEW_INTERNAL_CRIWV_BROWSER_STATE_H_
+#endif // IOS_WEB_VIEW_INTERNAL_WEB_VIEW_BROWSER_STATE_H_
« no previous file with comments | « ios/web_view/internal/translate/criwv_translate_client.mm ('k') | ios/web_view/internal/web_view_browser_state.mm » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698